@@ -1,5 +1,5 @@
 package Bot::Cobalt::Utils;
-our $VERSION = '0.016000';
+our $VERSION = '0.016001';
 
 use 5.10.1;
 use strict;
@@ -171,7 +171,7 @@ sub glob_to_re_str ($) {
     }
 
     ## Escape metas:
-    if (grep { $_ eq $ch } qw/ . ( ) . | ^ $ @ % { } /) {
+    if (grep { $_ eq $ch } qw/ . ( ) | ^ $ @ % { } /) {
       $re .= "\\$ch" ;
       $in_esc = 0;
       next
@@ -193,6 +193,11 @@ sub glob_to_re_str ($) {
       $in_esc = 0;
       next
     }
+    if ( $ch eq '[' || $ch eq ']' ) {
+      $re .= $in_esc ? "\\$ch" : $ch ;
+      $in_esc = 0;
+      next
+    }
 
     ## Switch on/off escaping:
     if ($ch eq "\\") {
